@@ -5,6 +5,31 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
         return playbackManager.getSubtitleUrl(subtitleStream, serverId);
     }
 
+    function toDecimal(val) {
+        return parseFloat(val) / 255;
+    }
+
+    function hexToRgbA(hex, alpha) {
+
+        if (hex === 'transparent') {
+            return hex;
+        }
+
+        var c;
+        if (/^#([A-Fa-f0-9]{3}){1,2}$/.test(hex)) {
+            c = hex.substring(1).split('');
+            if (c.length === 3) {
+                c = [c[0], c[0], c[1], c[1], c[2], c[2]];
+            }
+            c = '0x' + c.join('');
+
+            alpha = Math.min(1, alpha);
+            alpha = Math.max(0, alpha);
+            return [(c >> 16) & 255, (c >> 8) & 255, c & 255].map(toDecimal).join('/') + '/' + alpha;
+        }
+        throw new Error('Bad Hex');
+    }
+
     return function () {
 
         var self = this;
@@ -44,7 +69,8 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 category: 'Playback',
                 thumbImage: '',
                 icon: 'audiotrack',
-                settingsTheme: true
+                settingsTheme: true,
+                adjustHeaderForEmbeddedScroll: true
             });
 
             if (appHost.supports('windowtransparency')) {
@@ -57,7 +83,8 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                     category: 'Playback',
                     thumbImage: '',
                     icon: 'tv',
-                    settingsTheme: true
+                    settingsTheme: true,
+                    adjustHeaderForEmbeddedScroll: true
                 });
             }
 
@@ -317,6 +344,18 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 Format: 'smi',
                 Method: 'Embed'
             });
+            profile.SubtitleProfiles.push({
+                Format: 'mov_text',
+                Method: 'Embed'
+            });
+            profile.SubtitleProfiles.push({
+                Format: 'eia_608',
+                Method: 'VideoSideData'
+            });
+            profile.SubtitleProfiles.push({
+                Format: 'eia_708',
+                Method: 'VideoSideData'
+            });
 
             profile.ResponseProfiles = [];
 
@@ -574,19 +613,24 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                 playerOptions["sub-font-size"] = fontSize
             }
 
+            if (subtitleAppearanceSettings.textBackground) {
+                playerOptions["sub-back-color"] = hexToRgbA(subtitleAppearanceSettings.textBackground, parseFloat(subtitleAppearanceSettings.textBackgroundOpacity || '1'));
+            }
+
             if (subtitleAppearanceSettings.textColor && subtitleAppearanceSettings.textColor.indexOf('#') === 0) {
                 playerOptions["sub-color"] = subtitleAppearanceSettings.textColor
             }
 
 
-            await setProperty(Object.assign(playerOptions, audioDelay(), interlace(), getMpvAudioOptions(mediaType)))
+            await setProperty(Object.assign(playerOptions, audioDelay(), interlace(), createClosedCaptionTrack(mediaSource, isVideo), getMpvAudioOptions(mediaType)))
             await sendCommand(['loadfile', url])
 
             if (mediaSource.DefaultAudioStreamIndex && playMethod != 'Transcode') {
                 await setAudioStream(mediaSource.DefaultAudioStreamIndex);
             }
 
-            await setSubtitleStream(mediaSource.DefaultSubtitleStreamIndex)
+            var subtitleIndexToSet = mediaSource.DefaultSubtitleStreamIndex == null ? -1 : mediaSource.DefaultSubtitleStreamIndex;
+            await setSubtitleStream(subtitleIndexToSet)
             await setProperty({
                 start: `${Math.floor(startPositionTicks / 10000000)}`,
                 pause: false
@@ -980,6 +1024,22 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
             return Promise.resolve()
         }
 
+        function createClosedCaptionTrack(mediaSource, isVideo) {
+
+            var streams = mediaSource.MediaStreams || [];
+
+            for (var i = 0, length = streams.length; i < length; i++) {
+
+                var stream = streams[i];
+
+                if (stream.DeliveryMethod == 'VideoSideData') {
+                    return { 'sub-create-cc-track': 'yes' };
+                }
+            }
+
+            return { 'sub-create-cc-track': 'no' };
+        }
+
         function interlace() {
             var videoStream = (mediaSource.MediaStreams || []).filter(function (v) {
                 return v.Type == 'Video';
@@ -1068,6 +1128,16 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
             return '';
         }
 
+        function enableInternalSubtitleStream(stream, subIndex) {
+
+            return setProperty({ "sid": subIndex }).then(() => {
+                if (stream.Codec == "dvb_teletext") {
+                    return setDvbTeletextPage(stream);
+                }
+                return Promise.resolve()
+            })
+        }
+
         function setSubtitleStream(index) {
             setProperty({ "sub-delay": 0 })
             if (index === null || index < 0) {
@@ -1084,12 +1154,7 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                             if (stream.DeliveryMethod == 'External') {
                                 return sendCommand(["sub-add", stream.DeliveryUrl, "cached", stream.DisplayTitle, stream.Language]);
                             } else {
-                                return setProperty({ "sid": subIndex }).then(() => {
-                                    if (stream.Codec == "dvb_teletext") {
-                                        return setDvbTeletextPage(stream);
-                                    }
-                                    return Promise.resolve()
-                                })
+                                return enableInternalSubtitleStream(stream, subIndex);
                             }
                         }
                     }
@@ -1322,11 +1387,6 @@ define(['globalize', 'apphost', 'playbackManager', 'pluginManager', 'events', 'e
                     value: getDroppedFrames(responses)
                 });
 
-                stats.push({
-                    label: 'Display Fullscreen Resolution:',
-                    value: screen.width + ' x ' + screen.height
-                });
-
                 if (videoParams.w && videoParams.h) {
                     stats.push({
                         label: 'Video resolution:',
